"""
Tests for authenticated Web application framework.

Copyright 2017-2020 ICTU
Copyright 2017-2022 Leiden University
Copyright 2017-2023 Leon Helwerda

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

from argparse import Namespace
from configparser import RawConfigParser
import cherrypy
from cherrypy.test import helper
from server.application import Authenticated_Application

class TestServer(Authenticated_Application):
    """
    Test server.
    """

    @cherrypy.expose
    def index(self, page: str = 'list', params: str = '') -> str:
        return "Index page"

class AuthenticatedApplicationTest(helper.CPWebCase):
    """
    Tests for Web application that requires authentication.
    """

    @staticmethod
    def setup_server() -> None:
        """"
        Set up the application server.
        """

        args = Namespace()
        args.auth = 'open'
        args.debug = True

        config = RawConfigParser()
        config.read("test/settings.cfg")

        cherrypy.tree.mount(TestServer(args, config), '/', {
            '/': {
                'tools.sessions.on': True,
                'tools.sessions.httponly': True,
            }
        })

    def test_index(self) -> None:
        """
        Test the index page.
        """

        self.getPage("/")
        self.assertStatus('200 OK')
        self.assertBody('Index page')
